# Help & Support

Need a hand with using pyinfra or have some questions? You can find official pyinfra communities below:

+ Chat in [the `pyinfra` Matrix room](https://matrix.to/#/#pyinfra:matrix.org)
+ Ask questions on [Stack Overflow](https://stackoverflow.com/questions/tagged/pyinfra) (be sure to use the `pyinfra` tag!)

## I think I've got a bug!

+ Please have a quick scan of the [compatibility page](./compatibility) to see if the issue is referenced there
+ Check [the issue list](https://github.com/Fizzadar/pyinfra/issues) to see if anyone else has this issue
+ Submit [a new bug report](https://github.com/Fizzadar/pyinfra/issues/new/choose)

## I have an idea!

Please consider [submitting a feature request](https://github.com/Fizzadar/pyinfra/issues/new/choose).

## I'd like to contribute!

Fantastic! Please see [the contributing docs](./contributing).
